Simplified RTDB
---------------

Simplified access to the Request Tracker 4 database.

Using the RT api to get statistics is rather slow since fetching many tickets at
once is expensive. This app models RT4 queues, tickets, and ticket customfields.
